@@ -26,6 +26,7 @@ class SubgraphClient:
                 from
                 to
                 feed
+                overnightMaxLeverage
               }
             }
       """
@@ -43,7 +44,8 @@ class SubgraphClient:
             pair(id: $pair_id) {
               id
               from
-              to                    
+              to    
+              overnightMaxLeverage                
               longOI
               shortOI
               maxOI
@@ -100,7 +102,6 @@ class SubgraphClient:
             raise ValueError(f"No pair details found for pair ID: {pair_id}")
 
     async def get_liq_margin_threshold_p(self):
-        self.log(f"Fetching get_liq_margin_threshold_p")
         query = gql(
             """
           query metaDatas {
@@ -112,7 +113,13 @@ class SubgraphClient:
         )
         result = await self.client.execute_async(query)
 
-        return result['metaDatas'][0]['liqMarginThresholdP']
+        liq_margin_threshold_p = result['metaDatas'][0]['liqMarginThresholdP']
+
+        if self.verbose:
+            self.log(
+                f"Fetched get_liq_margin_threshold_p: {liq_margin_threshold_p}%")
+
+        return liq_margin_threshold_p
 
     async def get_open_trades(self, address):
         # self.log(f"Fetching open trades for address: {address}")
